var searchData=
[
  ['value_5ftype_0',['value_type',['../classgko_1_1array.html#a9a8aebb3d68396889cf98ca877808549',1,'gko::array::value_type'],['../classgko_1_1accessor_1_1row__major.html#a687bda931be92c31abf02965fa72ceba',1,'gko::accessor::row_major::value_type']]],
  ['view_5fdeleter_1',['view_deleter',['../classgko_1_1array.html#a377a6aaf5ee6c2747781b889eea6c226',1,'gko::array']]],
  ['void_5ft_2',['void_t',['../namespacegko_1_1xstd.html#a2d53b45325a9d6c46906d80caf180869',1,'gko::xstd']]]
];
